#!/bin/bash

# SLES 9 only
# This script is written in bash (instead of ksh) because it invokes SLES scripts

die() {
    echo $*
    echo "Uninstallation of HA-NFS failed."
    exit 0
}

logit() {
    $* >> $LOGFILE 2>&1
}

unconfig() {
    . /etc/rc.status

    rc_reset

    # Check for SUSE distribution
    dist=$( cat /etc/issue | grep "SUSE LINUX Enterprise Server 9" )
    if [ "$dist" == "" ]; then
	die "$0 will work only for SUSE LINUX Enterprise Server 9"
    fi

    # Check the GPFS is not running
    gpfs=$(mmfsadm dump version 2> /dev/null | grep "Current daemon version")
    if [ -n "$gpfs" ]; then
	echo "GPFS still running! Shutdown GPFS on all nodes (mmshutdown -a) before uninstall."
        return 1
    fi

    echo -n "Uninstalling GPFS service "
    if [ -f /etc/init.d/gpfs ]; then 
        logit insserv -d gpfs
        logit rm -f /etc/init.d/gpfs 
    fi
    # Redo GPFS autoload in inittab
    sed -i 's/^# gpfs:\(.*\)# Disabled by HA-NFS/gpfs:\1/g' /etc/inittab
    rc_status -v

    # Reset default start mode of interfaces used for HA-NFS
    gpfsip=$(myGPFSIP)
    nfsIPs=$(getNfsIPs $gpfsip)
    for ip in $nfsIPs; do
        # Find its ifcfg file
        ifcfg=$(grep -wl $ip $IFPATH/ifcfg-eth* 2> /dev/null)
	[ -z "$ifcfg" ] && continue
        iface=$(echo $ifcfg | sed 's/ifcfg-//g')
        if grep -q "^STARTMODE=\'manual\'" $ifcfg; then
            # SuSE
            sed -i "s/^STARTMODE='manual'	$ added for HA-NFS/STARTMODE='onboot'/g" $ifcfg
            echo "Uninstallation has changed the start mode of interface $iface to onboot"
        elif grep -q "^ONBOOT=no" $ifcfg; then
            # RedHat
            sed -i "s/^ONBOOT=no	# added for HA-NFS/^ONBOOT=yes/g" $ifcfg
            echo "Uninstallation has changed the start mode of interface $iface to onboot"
        fi
    done

    # Restore backup 
#    files="/var/mmfs/etc/mmfs.cfg /var/mmfs/etc/nfsdefs /var/mmfs/etc/alert $NODELIST"
#    for file in $files; do
#        [ -f $file ] && logit cp -dp $file /tmp/$(basename $file).$$
#    done
#    logit rm -rf /var/mmfs/etc/*
#    for file in $files; do
#        [ -f /tmp/$(basename $file).$$ ] && logit cp -dp /tmp/$(basename $file).$$ $file
#    done
    [ -d /var/mmfs/etc.bak ] && logit rm -rf /var/mmfs/etc && logit mv /var/mmfs/etc.bak /var/mmfs/etc

    # Reset files in /var/lib/nfs
    [ -L /var/lib/nfs/rmtab ] && rm /var/lib/nfs/rmtab && touch /var/lib/nfs/rmtab
    [ -L /var/lib/nfs/sm ] && rm /var/lib/nfs/sm && mkdir -p /var/lib/nfs/sm
    [ -L /var/lib/nfs/sm.bak ] && rm /var/lib/nfs/sm.bak && mkdir -p /var/lib/nfs/sm.bak
    rc_reset
}

defs=/var/mmfs/etc/nfsdefs
funcs=/var/mmfs/etc/nfsfuncs
[ -f $defs ] || die "Cannot find $defs. See /usr/lpp/mmfs/samples/nfscluster/README for installation instructions"
[ -f $funcs ] || die "Cannot find $funcs. See /usr/lpp/mmfs/samples/nfscluster/README for installation instructions"

. $defs
. $funcs
. /etc/rc.status

if [ -n "$GPFS_RSH" ]; then
    GPFS_rshPath=$(which $GPFS_RSH)
else
    GPFS_rshPath=$(which rsh)
fi
if [ -n "$GPFS_RCP" ]; then
    GPFS_rcpPath=$(which $GPFS_RCP)
else
    GPFS_rcpPath=$(which rcp)
fi

LOGFILE=/tmp/ha-nfs-uninstall.log
> $LOGFILE

allflag=""
case $1 in
    -a)
        allflag=yes
	;;
    -u)
        unconfig
        exit $?
	;;
    *)
	;;
esac
	
if [ -z "$allflag" ]; then
    unconfig
else
    # Run configuration on all GPFS nodes
    gpfsIPs=$(getAllGPFSIPs)

    echo -n "Synchronizing uninstall script to all nodes in the cluster "
    for ip in $gpfsIPs; do
        logit $GPFS_rcpPath $0 $ip:/tmp
    done
    rc_status -v

    echo -n "Uninstalling HA-NFS on all nodes in the cluster "
    gpfsIPs=$(echo $gpfsIPs | sed 's/ /,/g')
    [ -n "$gpfsIPs" ] && logit mmdshcmdRC $gpfsIPs /tmp/uninstall_ha-nfs.sh -u
    if [ $? -ne 0 ]; then
        rc_failed 1
    else
        rc_reset
    fi
    rc_status -v
fi

RC=$?
if [ $RC -eq 0 ]; then
    echo -n "Uninstallation is complete. "
else
    echo -n "Uninstallation failed. "
fi
echo "See $LOGFILE for details."
exit $RC
